<?php

use CRM_Loginsecurity_ExtensionUtil as E;

class CRM_Loginsecurity_Utils_Check_InvalidLogins {

  function check(&$messages) {
    $userFramework = CRM_Core_Config::singleton()->userFramework;

    if (!self::isDrupalWatchdogEnabled($userFramework)) {
      $messages[] = new CRM_Utils_Check_Message(
        'loginsecurity_failedlogins',
        E::ts('Failed login count is not implemented for your CMS yet'),
        E::ts('Login Security - Failed login count not implemented'),
        \Psr\Log\LogLevel::DEBUG,
        'fa-check'
      );
      return;
    }

    try {
      $count = self::drupalWatchdogCount();

      if ($count > 10) {
        $messages[] = new CRM_Utils_Check_Message(
          'loginsecurity_failedlogins',
          // @todo Fix the URL for the Drupal page using the Drupal function
          E::ts('%1 failed logins in the past hour. More information is available in the <a href="%2">Drupal watchdog</a>.', [1 => $count, 2 => '/admin/reports/dblog?type[]=user']),
          E::ts('Login Security - Failed Logins'),
          \Psr\Log\LogLevel::CRITICAL,
          'fa-check'
        );
      }
      else {
        $messages[] = new CRM_Utils_Check_Message(
          'loginsecurity_failedlogins',
          E::ts('%1 failed logins in the past hour.', [1 => $count]),
          E::ts('Login Security - Failed Logins'),
          \Psr\Log\LogLevel::INFO,
          'fa-check'
        );
      }
    }
    catch (\Exception $e) {
      $errorMessage = $e->getMessage();
      $messages[] = new CRM_Utils_Check_Message(
        'loginsecurity_failedlogins',
        E::ts('Could not count failed logins in the past hour: PHP Exception: %1', [1 => $errorMessage]),
        E::ts('Login Security - Error Checking for Failed Logins'),
        \Psr\Log\LogLevel::ERROR,
        'fa-check'
      );
    }
  }

  protected static function isDrupalWatchdogEnabled($userFramework) : bool {
    if ($userFramework == 'Drupal') {
      if (module_exists('dblog')) {
        return TRUE;
      }
    }
    elseif ($userFramework == 'Drupal8') {
      $moduleHandler = \Drupal::service('module_handler');
      if ($moduleHandler->moduleExists('dblog')) {
        return TRUE;
      }
    }

    return FALSE;
  }

  protected static function drupalWatchdogCount(): int {
    $config = CRM_Core_Config::singleton();
    $ufDSN = CRM_Utils_SQL::autoSwitchDSN($config->userFrameworkDSN);
    $drupalDb = DB::connect($ufDSN);
    $watchdogTableName = self::getDrupalDbPrefix() . 'watchdog';

    $sql = "SELECT count(*)
      FROM {$watchdogTableName}
      WHERE type = 'user'
        AND message LIKE 'Login attempt failed%'
        AND timestamp > UNIX_TIMESTAMP(NOW()) - 3600";

    $query = $drupalDb->query($sql);
    return $query->fetchRow()[0];
  }

  protected static function getDrupalDbPrefix(): string {
    global $databases;
    if (isset($databases['default']['default']['prefix'])) {
      if (is_array($databases['default']['default']['prefix'])) {
        return $databases['default']['default']['prefix']['default'];
      }
      else {
        return $databases['default']['default']['prefix'];
      }
    }
    return '';
  }

}
